@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2007 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -23,6 +23,7 @@
 #include "sebie_view.h"
 #include "sebie_gtk_helpers.h"
 #include "sebie_config.h"
+#include "../config.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <stdlib.h>
@@ -270,8 +271,12 @@ sebie_update_file_list(struct sebie_s *sebie)
   while((next = g_dir_read_name(gdir)) != NULL) {
     sebie_debug("next %s\n", next);
 
-    if (regexec(&sebie->model.regex, next, 0, NULL, 0) == 0) {
-      sebie_file_list_add(sebie, next);
+    if (sebie->model.regex_status) {
+      if (regexec(&sebie->model.regex, next, 0, NULL, 0) == 0) {
+	sebie_file_list_add(sebie, next);
+      }
+    } else {
+      sebie_debug("sebie->model.regex_status invalid");
     }
   }
 }
@@ -363,7 +368,7 @@ init_sebie_model(struct sebie_s *sebie)
   }
   
   sebie_config_spec config_spec[] = {
-    { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
+    { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "." },
     { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
     { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
     { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
@@ -382,6 +387,8 @@ init_sebie_model(struct sebie_s *sebie)
   sebie->model.input_file_path = NULL;
   sebie->model.output_file_path = NULL;
 
+  sebie->model.regex_status = 0;
+
   sebie->dirty_tags |= SEBIE_UPDATE_INPUT_PATH;
   sebie->dirty_tags |= SEBIE_UPDATE_INPUT_REGEX;
   sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FORMAT;
@@ -397,8 +404,10 @@ init_sebie_model(struct sebie_s *sebie)
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_H;
   sebie->dirty_tags |= SEBIE_UPDATE_IMAGE_GAMMA;
   
-  sebie->model.statusbar_text = strdup("   SeBIE  (C) 2002-2006 by Peter.Seiderer@ciselant.de");
+  sebie->model.statusbar_text = strdup("   SeBIE-" PACKAGE_VERSION " (C) 2002-2007 by Peter.Seiderer@ciselant.de");
   sebie->dirty_tags |= SEBIE_UPDATE_STATUS_BAR;
+
+  sebie_regcomp(sebie);
 }
 
 
