@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2007 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -41,21 +41,25 @@ on_treeview_file_list_changed(GtkTreeSelection *selection,
     gtk_tree_model_get(model, &iter, 0, &filename, -1);
     sebie_set_string(&sebie->model.input_file_name, filename);
     load_pixbuf(sebie);
-    int nmatch = 2;
-    regmatch_t matchptr[nmatch];
-    if (regexec(&sebie->model.regex, sebie->model.input_file_name, nmatch, matchptr, 0) == 0) {
-      char buf_regex[nmatch][256];
-      int i;
-      for (i = 0; i < nmatch; i++) {
-	strncpy(buf_regex[i],sebie->model.input_file_name +  matchptr[i].rm_so, matchptr[i].rm_eo - matchptr[i].rm_so);
-	buf_regex[i][matchptr[i].rm_eo - matchptr[i].rm_so] = '\0';
-	sebie_debug("buf_regex[%d] = %s\n", i, buf_regex[i]);
+    if (sebie->model.regex_status) {
+      int nmatch = 2;
+      regmatch_t matchptr[nmatch];
+      if (regexec(&sebie->model.regex, sebie->model.input_file_name, nmatch, matchptr, 0) == 0) {
+	char buf_regex[nmatch][256];
+	int i;
+	for (i = 0; i < nmatch; i++) {
+	  strncpy(buf_regex[i],sebie->model.input_file_name +  matchptr[i].rm_so, matchptr[i].rm_eo - matchptr[i].rm_so);
+	  buf_regex[i][matchptr[i].rm_eo - matchptr[i].rm_so] = '\0';
+	  sebie_debug("buf_regex[%d] = %s\n", i, buf_regex[i]);
+	}
+	char buf[256];
+	snprintf(buf, 256, sebie->model.output_format, buf_regex[1]);
+	sebie_set_string(&sebie->model.output_file_name, buf);
+	sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FILE_NAME;
+	sebie_update_view(sebie);
       }
-      char buf[256];
-      snprintf(buf, 256, sebie->model.output_format, buf_regex[1]);
-      sebie_set_string(&sebie->model.output_file_name, buf);
-      sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FILE_NAME;
-      sebie_update_view(sebie);
+    } else {
+      sebie_debug("sebie->model.regex_status invalid");
     }
   }
 }
@@ -81,13 +85,7 @@ on_entry_input_regex_changed (GtkEditable *editable,
   sebie_debug("input_regex = %s\n", input_regex);
   sebie_set_string(&sebie->model.input_regex, input_regex);
   sebie->model_tags |= SEBIE_MODEL_INPUT_REGEX;
-  int err;
-  if ((err = regcomp(&sebie->model.regex, input_regex, 0)) != 0) {
-    char buf[256];
-    regerror(err, &sebie->model.regex, buf, 256);
-    fprintf(stderr, "Error: regcomp failed (%s)\n", buf);
-    return;
-  }
+  sebie_regcomp(sebie);
   sebie_update_file_list(sebie);
 }
 
