@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -38,6 +38,19 @@ on_entry_input_regex_changed (GtkEditable *editable,
 void
 on_entry_output_format_changed (GtkEditable *editable,
 				gpointer    user_data);
+gint
+window1_delete_event (GtkWidget *widget,
+		      GdkEvent  *event,
+		      gpointer   data);
+
+void
+window1_destroy (GtkWidget *widget,
+		 gpointer   data);
+
+void
+drawingarea1_size_allocate (GtkWidget *widget,
+			    GtkAllocation *allocation,
+			    gpointer   data);
 
 void
 on_button_quit_clicked (GtkButton *button,
@@ -72,7 +85,7 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
 				  gpointer  user_data);
 
 void
-on_button_grayscale_clicked(GtkButton *button,
+on_button_grayscale_clicked(GtkToggleButton *button,
 			    gpointer  user_data);
 
 gboolean
