@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2003-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -19,6 +19,7 @@
  *
  */
 #include "sebie_config.h"
+#include "sebie_helpers.h"
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -44,7 +45,7 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
   char *tmp;
   int i = 0;
   
-  // init with default values
+  /* init with default values */
   while (spec[i].type != CONFIG_END) {
     switch (spec[i].type) {
     case CONFIG_INTEGER:
@@ -57,14 +58,16 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
       *spec[i].storage.string = g_strdup(spec[i].defvalue.string);
       break;
     default:
-      fprintf(stderr, "Error: unknonw config type %d.\n", spec[i].type);
+      sebie_error("Error: unknown config type %d.\n", spec[i].type);
+      return 1;
     }
     i++;
   }
 
   if ((file = fopen(path, "r")) == NULL) {
-    fprintf(stderr, "Error: open of config file %s failed (%s).\n",
-	    path, strerror(errno));
+    sebie_debug("open of config file %s failed (%s).\n",
+		path,
+		strerror(errno));
     return 1;
   }
   
@@ -83,7 +86,7 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
     
     *eqs = '\0';
 
-    // eat spaces
+    /* eat spaces */
     tmp =  eqs -1;
     while (tmp >= buf) {
       if (*tmp == ' ') {
@@ -95,7 +98,7 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
     }
     name = buf;
 
-    // eat spaces
+    /* eat spaces */
     tmp =  eqs +1;
     while (*tmp != '\0') {
       if (*tmp == ' ') {
@@ -124,7 +127,9 @@ sebie_read_config(const char *path, sebie_config_spec *spec)
 	  *spec[i].storage.string = g_strdup(value);
 	  break;
 	default:
-	  fprintf(stderr, "Error: unknonw config type %d.\n", spec[i].type);
+	  sebie_error("Error: unknown config type %d.\n", spec[i].type);
+	  fclose(file);
+	  return 1;
 	}
       }
       i++;
@@ -161,7 +166,8 @@ sebie_write_config(const char *path, sebie_config_spec *spec)
       fprintf(file, "%s=%s\n", spec[i].name, *spec[i].storage.string);
       break;
     default:
-      fprintf(stderr, "Error: unknonw config type %d.\n", spec[i].type);
+	/* write out error and ignore */
+      sebie_error("Error: unknown config type %d.\n", spec[i].type);
     }
     i++;
   }
