@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2007 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -19,10 +19,13 @@
  *
  */
 #include "sebie_helpers.h"
+#include "sebie.h"
+
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
 
+
 void
 sebie_set_string(gchar **old_text, const gchar *new_text)
 {
@@ -53,3 +56,17 @@ sebie_debug(const char *format, ...)
     va_end(ap);
   }
 }
+
+void
+sebie_regcomp(struct sebie_s *sebie)
+{
+  int err;
+  if ((err = regcomp(&sebie->model.regex, sebie->model.input_regex, 0)) != 0) {
+    char buf[256];
+    regerror(err, &sebie->model.regex, buf, 256);
+    fprintf(stderr, "Error: regcomp failed (%s)\n", buf);
+    sebie->model.regex_status = 0;
+    return;
+  }
+  sebie->model.regex_status = 1;
+}
