@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2007 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -23,6 +23,8 @@
 
 #include <gdk/gdk.h>
 
+struct sebie_s;
+
 void
 sebie_set_string(gchar **old_text, const gchar *new_text);
 
@@ -32,4 +34,7 @@ sebie_error(const char *format, ...);
 void
 sebie_debug(const char *format, ...);
 
+void
+sebie_regcomp(struct sebie_s *sebie);
+
 #endif /* _SEBIE_HELPERS_H_ */
